MIN_LENGTH = 1
MAX_LENGTH = 400

IDENTIFIER_REGEX_CONDITION = r"^[A-Za-z0-9\.\-:_,=\/@]+$"
MSMQ_NAME_REGEX_CONDITION = r"^[A-Za-z0-9_\.]+$"
NAME_REGEX_CONDITION = r"^[A-Za-z0-9/\-_:,\s@\.]+$"


ORG = "ORG"
APPLICATION = "APP"
PROJECT = "PRJ"
TYPE = "TYPE"
NAMESPACE = "NS"

# SERVICE_CONFIG_ID
SERVICE_CONFIG_ID_REMIND = "remind"
SERVICE_CONFIG_ID_UTILS = "utils"
SERVICE_CONFIG_ID_SSO_FE = "sso_fe"
SERVICE_CONFIG_ID_SSO_API = "sso_api"
SERVICE_CONFIG_ID_GATEWAY = "gateway"
SERVICE_CONFIG_ID_CERTS = "certs"
SERVICE_CONFIG_ID_PERMS = "perms"

# COMMON ACTIONS
UID_ACTION_CREATE = "CREATE_UID"
UID_ACTION_DELETE = "DELETE_UID"
UID_ACTION_UPDATE = "UPDATE_UID"

OID_ACTION_CREATE = "CREATE_OID"
OID_ACTION_DELETE = "DELETE_OID"
OID_ACTION_UPDATE = "UPDATE_OID"

TID_ACTION_CREATE = "CREATE_TID"
TID_ACTION_DELETE = "DELETE_TID"
TID_ACTION_UPDATE = "UPDATE_TID"

PID_ACTION_CREATE = "CREATE_PID"
PID_ACTION_DELETE = "DELETE_PID"
PID_ACTION_UPDATE = "UPDATE_PID"

CID_ACTION_CREATE = "CREATE_CID"
CID_ACTION_DELETE = "DELETE_CID"
CID_ACTION_UPDATE = "UPDATE_CID"

OUTPOST_ACTION_CLEAR = "CLEAR_OUTPOST"
REMIND_ACTION_CREATE = "CREATE_REMINDER"
REMIND_ACTION_DELETE = "DELETE_REMINDER"
REMIND_ACTION_IN_MINS = 60
